@@ -6,10 +6,14 @@
 
 // Globals that we ourselves define.
 var hiddenStuffHeight, mainContentHeight, sidebarHeight, mainContentWidth,
-    verticalItemHeight, accordion, resizeTimer;
+    verticalItemHeight, accordion, resizeTimer, cachedScrollbarWidth;
 
 
 function scrollbarWidth() {
+    return cachedScrollbarWidth;
+}
+
+function calculateScrollbarWidth() {
     // Copied from http://jdsharp.us/jQuery/minute/calculate-scrollbar-width.php
     var div, w1, w2;
     div = $('<div style="width:50px;height:50px;overflow:hidden;' +
@@ -21,10 +25,9 @@ function scrollbarWidth() {
     div.css('overflow-y', 'scroll');
     w2 = $('div', div).innerWidth();
     $(div).remove();
-    return (w1 - w2);
+    cachedScrollbarWidth = (w1 - w2);
 }
 
-
 function reloadGraphs(max_image_width) {
     $('a.replace-with-image').each(
         function (index) {
@@ -356,23 +359,27 @@ function setUpAccordion() {
     /* Set up a global 'accordion' variable to later steer the animation. */
     accordion = $("#accordion").data("tabs");
     $(".accordion-load-next a").live('click', function (event) {
-        var pane, nextPaneId, url, newTitle;
+        var pane, nextPaneId, url, newTitle, ourId;
         event.preventDefault();
         pane = $(this).parents(".accordion-load-next");
         nextPaneId = pane.attr("data-next-pane-id");
         url = $(this).attr("href");
         $(nextPaneId).html('<div class="loading" />');
         $.get(url, {}, function (data) {
-            // Update all panes. Data is the whole (new) html page.
+            // Update all pane titles and the new pane. Data is the whole
+            // (new) html page.
             $(".pane").each(function () {
                 // Title of current pane.
                 newTitle = $(data).find("#" + $(this).attr("id")).prev().html();
                 $(this).prev().html(newTitle);
-                // Content of current pane.
-                $(this).html($(data).find("#" + $(this).attr("id")).html());
+                // Refresh target pane contents only.
+                ourId = "#" + $(this).attr("id");
+                if (ourId === nextPaneId) {
+                    $(this).html($(data).find(ourId));
+                }
             });
             setUpTooltips();
-            setUpTree(true);
+            setUpTree();
         });
         $("li.selected", pane).removeClass("selected");
         $(this).parent("li").addClass("selected");
@@ -448,7 +455,6 @@ function setUpScreen() {
     stretchOneSidebarBox();
 }
 
-
 function setUpPortalTabs() {
     var selected_tab;
     selected_tab = $("#portal-tab-selected").attr("data-selected");
@@ -480,8 +486,8 @@ $(window).resize(function () {
     );
 });
 
-
 $(document).ready(function () {
+    calculateScrollbarWidth();
     calculateHiddenStuffHeight();
     fillScreen();
     divideVerticalSpaceEqually();
